@@ -23,9 +23,13 @@ class R3sponse(object):
 		#
 
 	# response functions.
-	def default_response(self):
-		return self.ResponseObject()
-	def success_response(self,
+	def default_response(self, attributes={
+		"success":False,
+		"message":None,
+		"error":None,
+	}):
+		return self.ResponseObject(attributes=attributes)
+	def success(self,
 		# the message (must be param #1).
 		message, 
 		# additional returnable functions (must be param #2).
@@ -37,10 +41,11 @@ class R3sponse(object):
 		# return as a django JsonResponse.
 		django=False,
 	):
-		response = self.default_response()
-		response["success"] = True
-		response["message"] = message
-		response["error"] = None
+		response = self.default_response({
+			"success":True,
+			"message":message,
+			"error":None,
+		})
 		for key, value in variables.items():
 			response[key] = value
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
@@ -50,7 +55,7 @@ class R3sponse(object):
 			except AttributeError:
 				response = JsonResponse(response)
 		return response
-	def error_response(self,
+	def error(self,
 		# the error message.
 		error="", 
 		# log log level of the message (int).
@@ -60,10 +65,11 @@ class R3sponse(object):
 		# return as a django JsonResponse.
 		django=False,
 	):
-		response = self.default_response()
-		response["success"] = False
-		response["message"] = None
-		response["error"] = error
+		response = self.default_response({
+			"success":False,
+			"message":None,
+			"error":error,
+		})
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
 		if django: 
 			try:
@@ -72,10 +78,6 @@ class R3sponse(object):
 				response = JsonResponse(response)
 		return response
 		#
-	def success(self, response):
-		if response["error"] == None:
-			return True
-		else: return False
 
 	# parameter functions.
 	def get_request_parameter(self, request, identifier):
@@ -91,7 +93,7 @@ class R3sponse(object):
 		else:
 			variable = request.GET.get(identifier)
 		if variable in ["", None]:
-			return variable, self.error_response(f"Define parameter: [{identifier}].")
+			return variable, self.error(f"Define parameter: [{identifier}].")
 		elif format != None:
 			if format in ["str", "string"]: variable = str(variable)
 			elif format in ["int", "integer"]: variable = int(variable)
@@ -102,13 +104,13 @@ class R3sponse(object):
 			elif format in ["array", "list"]: variable = variable.split(",")
 			else:
 				raise ValueError(f"Unrecognized <r3sponse.get_request_parameter> format: {format}.")
-		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].", {
+		return variable, self.success(f"Succesfully retrieved request parameter [{identifier}].", {
 			"key":identifier,
 			"value":variable,
 		})
 	def get_request_parameters(self, request, identifiers=[], optional=False, empty_value=None):
 		if isinstance(identifiers, str):
-			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
+			return self.error("__get_request_params__ is used to retrieve several identifiers (array format not string).")
 		params = self.ResponseObject()
 		for param in identifiers:
 			param_value, response = self.get_request_parameter(request, param)
@@ -124,13 +126,13 @@ class R3sponse(object):
 			for key in identifiers:
 				try: params[key]
 				except: params[key] = empty_value
-		return params, self.success_response(f"Succesfully retrieved {len(params)} request parameter(s).")
+		return params, self.success(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 	# check parameters.
 	def check_parameter(self, parameter=None, name="parameter", empty_value=None):
 		response = self.default_response()
 		if parameter == empty_value: 
-			return self.error_response(f"Define parameter [{name}].")
+			return self.error(f"Define parameter [{name}].")
 		if ":" in name:
 			name,formats = name.split(":")
 			while True:
@@ -139,8 +141,8 @@ class R3sponse(object):
 			formats = formats.split(",")
 			param_format = Formats.get(parameter, serialize=True)
 			if param_format not in formats:
-				return self.error_response(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
-		return self.success_response(f"Succesfully checked parameter [{name}].")
+				return self.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
+		return self.success(f"Succesfully checked parameter [{name}].")
 	def check_parameters(self, parameters={"parameter":None}, empty_value=None):
 		response = self.default_response()
 		for id, value in parameters.items():
@@ -195,9 +197,9 @@ class R3sponse(object):
 				if response != {}:
 					print(response.json())
 				elif error != None:
-					print(self.error_response(error))
+					print(self.error(error))
 				else:
-					print(self.success_response(message))
+					print(self.success(message))
 			else:
 				print(f"{color.fill(msg)}")
 		if save: 
@@ -210,7 +212,7 @@ class R3sponse(object):
 		try:
 			logs = Formats.File(self.log_file, load=True, blank="").data
 		except:
-			return self.error_response("Failed to load the logs.")
+			return self.error("Failed to load the logs.")
 		if format == "webserver":
 			logs = logs.replace("\n", "<br>")
 		elif format == "cli":
@@ -220,9 +222,9 @@ class R3sponse(object):
 		elif format == "string" or format == str:
 			logs = str(logs)
 		else: 
-			return self.error_response(f"Invalid format parameter [{format}], valid options: {options}.")
+			return self.error(f"Invalid format parameter [{format}], valid options: {options}.")
 
-		return self.success_response("Succesfully loaded the logs.", {"logs":logs})
+		return self.success("Succesfully loaded the logs.", {"logs":logs})
 	def reset_logs(self):
 		Formats.File(self.log_file).save(f"Resetted log file.\n")
 		#
@@ -307,14 +309,47 @@ class R3sponse(object):
 			# import a dumped json response (str) (ignores attributes).
 			json=None,
 		):
-			if isinstance(json, str):
-				self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
-			elif isinstance(json, dict):
-				self.assign(json)
-			elif json != None:
-				raise ValueError("Invalid usage, the r3sponse.ResponseObject json parameter must be str / dict format.")
+
+			# assign attributes.
+			if json != None:
+				if isinstance(json, str):
+					self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
+				elif isinstance(json, dict):
+					self.assign(json)
+				elif json != None:
+					raise ValueError("Invalid usage, the r3sponse.ResponseObject json parameter must be str / dict format.")
 			else:
 				self.assign(attributes)
+
+			# clean message & error.
+			if self.message != None:
+				self.message = Formats.String(self.message).capitalized_word()
+			if self.error != None:
+				self.error = Formats.String(self.error).capitalized_word()
+			while True:
+				if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
+					self.message = self.message[:-1]
+				elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
+					self.error = self.error[:-1]
+				elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
+					self.error = Formats.String(self.error[len("Error: "):]).capitalized_word()
+				else: break
+			
+			# add dot.
+			if self.message != None  and len(self.message) > 0 and self.message[len(self.message)-1] not in ["!", "?"]:
+				self.message += "."
+			if self.error != None  and len(self.error) > 0 and self.error[len(self.error)-1] not in ["!", "?"]:
+				self.error += "."
+
+			# check error passed as success response. & reversed
+			if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
+				#_traceback_.print_exc() 
+				raise ValueError("The first x characters of a success response may not be [Failed].")
+			if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
+				#_traceback_.print_exc() 
+				raise ValueError("The first x characters of an error response may not be [Success].")
+			#quit()
+
 		# iterate over self keys & variables.
 		def items(self):
 			return vars(self).items()
@@ -384,6 +419,7 @@ class R3sponse(object):
 				r3sponse.log(error=self["error"], json=json)
 				sys.exit(1)
 			else:
+				#_traceback_.print_exc() 
 				if not traceback:
 					sys.tracebacklimit = -1 ; sys.traceback_limit = -1
 				if error.lower() in ["valueerror"]: raise Exception(self["error"])
